@@ -13,6 +13,7 @@
 #include <katedocument.h>
 #include <kateglobal.h>
 #include <kateview.h>
+#include <kateviewinternal.h>
 #include <ktexteditor/message.h>
 #include <ktexteditor/movingcursor.h>
 
@@ -456,13 +457,14 @@ void KateViewTest::testDragAndDrop()
 void KateViewTest::testGotoMatchingBracket()
 {
     KTextEditor::DocumentPrivate doc(false, false);
-    doc.setText("foo(bar)baz");
+    doc.setText("foo(bar)baz[]");
     //           0123456789
 
     KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
     const KTextEditor::Cursor cursor1(0, 3); // Starting point on open (
     const KTextEditor::Cursor cursor2(0, 8); // Insert Mode differ slightly from...
     const KTextEditor::Cursor cursor3(0, 7); // Overwrite Mode
+    const KTextEditor::Cursor cursor4(0, 11); // Test adjacents brackets (start at [)
 
     doc.config()->setOvr(false); // Insert Mode
 
@@ -480,6 +482,14 @@ void KateViewTest::testGotoMatchingBracket()
     view->toMatchingBracket();
     QCOMPARE(view->cursorPosition(), cursor1);
 
+    view->setCursorPosition(cursor4 + KTextEditor::Cursor(0, 1));
+    view->toMatchingBracket();
+    QCOMPARE(view->cursorPosition(), cursor4);
+    view->toMatchingBracket();
+    view->setCursorPosition(view->cursorPosition() + KTextEditor::Cursor(0, 1));
+    view->toMatchingBracket();
+    QCOMPARE(view->cursorPosition(), cursor4);
+
     doc.config()->setOvr(true); // Overwrite Mode
 
     view->setCursorPosition(cursor1);
@@ -532,4 +542,149 @@ void KateViewTest::testFindSelected()
     QCOMPARE(view->cursorPosition(), cursor3);
 }
 
+void KateViewTest::testTransposeWord()
+{
+    KTextEditor::DocumentPrivate doc(false, false);
+    doc.setText(
+        "swaps forward\n"
+        "wordAbove\n"
+        "wordLeft (_skips]Spaces.__And___}Sym_bols))))    wordRight)\n"
+        "wordBelow anotherWord yetAnotherWord\n");
+
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    const KTextEditor::Cursor swaps(0, 2); // swa|ps
+    const KTextEditor::Cursor wordAbove(1, 4); // wordA|bove
+    const KTextEditor::Cursor wordLeft(2, 1); // wo|rdLeft
+    const KTextEditor::Cursor skips(2, 10); // |_skips
+    const KTextEditor::Cursor And(2, 27); // __A|nd___
+    const KTextEditor::Cursor wordBelow(3, 0); // w|ordBelow
+
+    view->setCursorPosition(swaps);
+    QCOMPARE(view->cursorPosition(), swaps);
+    QCOMPARE(view->doc()->characterAt(view->cursorPosition()), "a");
+    view->transposeWord();
+    QCOMPARE(view->cursorPosition(), swaps + KTextEditor::Cursor(0, 8)); // " forward" has 8 characters
+    QCOMPARE(view->doc()->characterAt(view->cursorPosition()), "a"); // retain relative position inside the word
+
+    view->transposeWord();
+    QCOMPARE(view->cursorPosition(), swaps); // when the word is already last in line, swap backwards instead
+
+    view->setCursorPosition(wordAbove);
+    view->transposeWord();
+    QCOMPARE(view->cursorPosition(), wordAbove); // when there is no other word in the line, do nothing
+    QCOMPARE(view->doc()->characterAt(view->cursorPosition()), "A");
+
+    view->setCursorPosition(wordLeft);
+    view->transposeWord();
+    QCOMPARE(view->cursorPosition(), wordLeft); // when next word is invalid (made up of only symbols, in this case "(") do nothing
+    QCOMPARE(view->doc()->characterAt(view->cursorPosition()), "o");
+
+    view->setCursorPosition(skips);
+    view->transposeWord();
+    QCOMPARE(view->cursorPosition(), skips + KTextEditor::Cursor(0, 7)); // transpose word beginning with a symbol
+    QCOMPARE(view->doc()->characterAt(view->cursorPosition()), "_");
+
+    view->setCursorPosition(And);
+    view->transposeWord();
+    // skip multiple symbols if there is no space between current word and the symbols (in contrast to the case of wordLeft).
+    // Can be useful for e.g. transposing function arguments
+    QCOMPARE(view->cursorPosition(), And + KTextEditor::Cursor(0, 9));
+
+    view->transposeWord();
+    QCOMPARE(view->cursorPosition(), And + KTextEditor::Cursor(0, 9 + 17)); // next "word" is invalid as it is only a single "(", so do nothing
+
+    view->setCursorPosition(wordBelow);
+    view->transposeWord();
+    QCOMPARE(view->cursorPosition(), wordBelow + KTextEditor::Cursor(0, 12));
+    view->transposeWord();
+    QCOMPARE(view->cursorPosition(), wordBelow + KTextEditor::Cursor(0, 12 + 15));
+    view->transposeWord();
+    QCOMPARE(view->cursorPosition(), wordBelow + KTextEditor::Cursor(0, 12)); // end of line, transpose backwards instead
+}
+
+#include <iostream>
+void KateViewTest::testFindMatchingFoldingMarker()
+{
+    KTextEditor::DocumentPrivate doc(false, false);
+    doc.setMode(QString("Bash"));
+    doc.setHighlightingMode(QString("Bash"));
+
+    doc.setText(
+        "for i in 0 1 2; do\n"
+        "    if [[ i -lt 1 ]]; then echo $i; fi\n"
+        "    if [[ i -eq 2 ]]; then\n"
+        "        echo 'hello :)'\n"
+        "    fi\n"
+        "done\n");
+
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    KateViewInternal *viewInternal = view->getViewInternal();
+
+    const int ifvalue = doc.buffer().plainLine(1)->foldings()[0].foldingValue;
+    const int dovalue = doc.buffer().plainLine(0)->foldings()[0].foldingValue;
+
+    const KTextEditor::Range firstDo(0, 16, 0, 18);
+    const KTextEditor::Range firstDoMatching(5, 0, 5, 4);
+    const KTextEditor::Range firstIf(1, 4, 1, 6);
+    const KTextEditor::Range firstIfMatching(1, 36, 1, 38);
+
+    // first test the do folding marker with cursor above first position of the word.
+    QCOMPARE(viewInternal->findMatchingFoldingMarker(firstDo.start(), dovalue, 2000), firstDoMatching);
+    // with cursor above last position of the word
+    QCOMPARE(viewInternal->findMatchingFoldingMarker(firstDo.end(), dovalue, 2000), firstDoMatching);
+    // now to test the maxLines param.
+    QCOMPARE(viewInternal->findMatchingFoldingMarker(firstDo.start(), dovalue, 2), KTextEditor::Range::invalid());
+
+    // it must work from end folding to start folding too.
+    QCOMPARE(viewInternal->findMatchingFoldingMarker(firstDoMatching.start(), -dovalue, 2000), firstDo);
+    QCOMPARE(viewInternal->findMatchingFoldingMarker(firstDoMatching.start(), -dovalue, 2), KTextEditor::Range::invalid());
+
+    // folding in the same line
+    QCOMPARE(viewInternal->findMatchingFoldingMarker(firstIf.start(), ifvalue, 2000), firstIfMatching);
+    QCOMPARE(viewInternal->findMatchingFoldingMarker(firstIfMatching.start(), -ifvalue, 2000), firstIf);
+}
+
+void KateViewTest::testUpdateFoldingMarkersHighlighting()
+{
+    KTextEditor::DocumentPrivate doc(false, false);
+    doc.setMode(QString("Bash"));
+    doc.setHighlightingMode(QString("Bash"));
+
+    doc.setText(
+        "for i in 0 1 2; do\n"
+        "    if [[ i -lt 1 ]]; then echo $i; fi\n"
+        "    if [[ i -eq 2 ]]; then\n"
+        "        echo 'hello :)'\n"
+        "    fi\n"
+        "done\n");
+
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    KateViewInternal *viewInternal = view->getViewInternal();
+
+    const KTextEditor::Cursor positionWithoutMarker(0, 4);
+    const KTextEditor::Range firstDo(0, 16, 0, 18);
+    const KTextEditor::Range firstDoMatching(5, 0, 5, 4);
+
+    KTextEditor::MovingRange *foldingMarkerStart = viewInternal->m_fmStart.get();
+    KTextEditor::MovingRange *foldingMarkerEnd = viewInternal->m_fmEnd.get();
+
+    // If the cursor is not above any folding marker, the highlighting range is invalid
+    view->editSetCursor(positionWithoutMarker);
+    viewInternal->updateFoldingMarkersHighlighting();
+    QCOMPARE(foldingMarkerStart->toRange(), KTextEditor::Range::invalid());
+    QCOMPARE(foldingMarkerEnd->toRange(), KTextEditor::Range::invalid());
+
+    // If the cursor is above a opening folding marker, the highlighting range is the range of both opening and end folding markers words
+    view->editSetCursor(firstDo.start());
+    viewInternal->updateFoldingMarkersHighlighting();
+    QCOMPARE(foldingMarkerStart->toRange(), firstDo);
+    QCOMPARE(foldingMarkerEnd->toRange(), firstDoMatching);
+
+    // If the cursor is above a ending folding marker, then same rule above
+    view->editSetCursor(firstDoMatching.start());
+    viewInternal->updateFoldingMarkersHighlighting();
+    QCOMPARE(foldingMarkerStart->toRange(), firstDo);
+    QCOMPARE(foldingMarkerEnd->toRange(), firstDoMatching);
+}
+
 // kate: indent-mode cstyle; indent-width 4; replace-tabs on;
