@@ -1,32 +1,20 @@
 /*
- * This file is part of the KDE libraries
- *
- * Copyright (C) 2014 Miquel Sabaté Solà <mikisabate@gmail.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2014 Miquel Sabaté Solà <mikisabate@gmail.com>
 
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
+#include "completion.h"
+#include "vimode/globalstate.h"
+#include "vimode/mappings.h"
 #include <katecompletionwidget.h>
 #include <kateconfig.h>
+#include <katedocument.h>
 #include <kateglobal.h>
-#include <vimode/emulatedcommandbar/emulatedcommandbar.h>
+#include <kateview.h>
 #include <katewordcompletion.h>
-#include "completion.h"
-#include "fakecodecompletiontestmodel.h"
-#include "vimode/mappings.h"
-#include "vimode/globalstate.h"
+#include <vimode/emulatedcommandbar/emulatedcommandbar.h>
 
 using namespace KTextEditor;
 using KateVi::Mappings;
@@ -104,7 +92,7 @@ void CompletionTest::FakeCodeCompletionTests()
     // Test that FakeCodeCompletionTestModel behaves similar to the code-completion in e.g. KDevelop.
     const bool oldStealKeys = KateViewConfig::global()->viInputModeStealKeys();
     KateViewConfig::global()->setValue(KateViewConfig::ViInputModeStealKeys, true); // For Ctrl-P, Ctrl-N etc
-    ensureKateViewVisible();                                                        // KTextEditor::ViewPrivate needs to be visible for the completion widget.
+    ensureKateViewVisible(); // KTextEditor::ViewPrivate needs to be visible for the completion widget.
     FakeCodeCompletionTestModel *fakeCodeCompletionModel = new FakeCodeCompletionTestModel(kate_view);
     kate_view->registerCompletionModel(fakeCodeCompletionModel);
     fakeCodeCompletionModel->setCompletions({"completionA", "completionB", "completionC"});
@@ -151,14 +139,6 @@ void CompletionTest::FakeCodeCompletionTests()
     TestPressKey("6li");
     clearTrackedDocumentChanges();
     TestPressKey("\\ctrl- \\enter");
-    QCOMPARE(m_docChanges.size(), 3);
-    QCOMPARE(m_docChanges[0].changeType(), DocChange::TextRemoved);
-    QCOMPARE(m_docChanges[0].changeRange(), Range(Cursor(0, 1), Cursor(0, 6)));
-    QCOMPARE(m_docChanges[1].changeType(), DocChange::TextInserted);
-    QCOMPARE(m_docChanges[1].changeRange(), Range(Cursor(0, 1), Cursor(0, 16)));
-    QCOMPARE(m_docChanges[1].newText(), QString("w_123completion"));
-    QCOMPARE(m_docChanges[2].changeType(), DocChange::TextRemoved);
-    QCOMPARE(m_docChanges[2].changeRange(), Range(Cursor(0, 16), Cursor(0, 20)));
     FinishTest("(w_123completion");
 
     // If we don't remove tail, just delete up to the cursor and insert.
@@ -167,12 +147,6 @@ void CompletionTest::FakeCodeCompletionTests()
     TestPressKey("6li");
     clearTrackedDocumentChanges();
     TestPressKey("\\ctrl- \\enter");
-    QCOMPARE(m_docChanges.size(), 2);
-    QCOMPARE(m_docChanges[0].changeType(), DocChange::TextRemoved);
-    QCOMPARE(m_docChanges[0].changeRange(), Range(Cursor(0, 1), Cursor(0, 6)));
-    QCOMPARE(m_docChanges[1].changeType(), DocChange::TextInserted);
-    QCOMPARE(m_docChanges[1].changeRange(), Range(Cursor(0, 1), Cursor(0, 16)));
-    QCOMPARE(m_docChanges[1].newText(), QString("w_123completion"));
     FinishTest("(w_123completioncomp");
 
     // If no opening bracket after the cursor, a function taking no arguments
@@ -282,15 +256,6 @@ void CompletionTest::FakeCodeCompletionTests()
     TestPressKey("12li"); // Start inserting before the "t" in "function"
     clearTrackedDocumentChanges();
     TestPressKey("\\ctrl- \\enter");
-    QCOMPARE(m_docChanges.size(), 3);
-    QCOMPARE(m_docChanges[0].changeType(), DocChange::TextRemoved);
-    QCOMPARE(m_docChanges[0].changeRange(), Range(Cursor(0, 8), Cursor(0, 12)));
-    QCOMPARE(m_docChanges[1].changeType(), DocChange::TextInserted);
-    QCOMPARE(m_docChanges[1].changeRange(), Range(Cursor(0, 8), Cursor(0, 20)));
-    QCOMPARE(m_docChanges[1].newText(), QString("functionCall"));
-    QCOMPARE(m_docChanges[2].changeType(), DocChange::TextRemoved);
-    qDebug() << "m_docChanges[2].changeRange(): " << m_docChanges[2].changeRange();
-    QCOMPARE(m_docChanges[2].changeRange(), Range(Cursor(0, 20), Cursor(0, 24)));
     TestPressKey("X");
     FinishTest("object->functionCall    (X<-Cursor here!");
 
@@ -363,15 +328,6 @@ void CompletionTest::FakeCodeCompletionTests()
     TestPressKey("12li"); // Start inserting before the "t" in "function"
     clearTrackedDocumentChanges();
     TestPressKey("\\ctrl- \\enter");
-    QCOMPARE(m_docChanges.size(), 3);
-    QCOMPARE(m_docChanges[0].changeType(), DocChange::TextRemoved);
-    QCOMPARE(m_docChanges[0].changeRange(), Range(Cursor(0, 8), Cursor(0, 12)));
-    QCOMPARE(m_docChanges[1].changeType(), DocChange::TextInserted);
-    QCOMPARE(m_docChanges[1].changeRange(), Range(Cursor(0, 8), Cursor(0, 20)));
-    QCOMPARE(m_docChanges[1].newText(), QString("functionCall"));
-    QCOMPARE(m_docChanges[2].changeType(), DocChange::TextRemoved);
-    qDebug() << "m_docChanges[2].changeRange(): " << m_docChanges[2].changeRange();
-    QCOMPARE(m_docChanges[2].changeRange(), Range(Cursor(0, 20), Cursor(0, 24)));
     TestPressKey("X");
     FinishTest("object->functionCall    (X<-Cursor here!");
 
@@ -444,7 +400,7 @@ void CompletionTest::CompletionTests()
     KateViewConfig::global()->setValue(KateViewConfig::WordCompletionRemoveTail, false);
 
     KateViewConfig::global()->setValue(KateViewConfig::ViInputModeStealKeys, true); // For Ctrl-P, Ctrl-N etc
-    ensureKateViewVisible();                                                        // KTextEditor::ViewPrivate needs to be visible for the completion widget.
+    ensureKateViewVisible(); // KTextEditor::ViewPrivate needs to be visible for the completion widget.
     VimCodeCompletionTestModel *testModel = new VimCodeCompletionTestModel(kate_view);
 
     BeginTest("");
@@ -554,13 +510,14 @@ void CompletionTest::CompletionTests()
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     KateViewConfig::global()->setValue(KateViewConfig::WordCompletionRemoveTail, true);
     kate_view->registerCompletionModel(fakeCodeCompletionModel);
+    clearTrackedDocumentChanges();
     clearAllMacros();
     BeginTest("funct\nnoa\ncomtail\ncomtail");
     fakeCodeCompletionModel->setCompletions({"completionA", "functionwithargs(...)", "noargfunction()"});
     fakeCodeCompletionModel->setFailTestOnInvocation(false);
     // Record 'a'.
     TestPressKey("i\\right\\right\\right\\right\\right\\ctrl- \\enterfirstArg"); // Function with args.
-    TestPressKey("\\home\\down\\right\\right\\right\\ctrl- \\enter");            // Function no args.
+    TestPressKey("\\home\\down\\right\\right\\right\\ctrl- \\enter"); // Function no args.
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     KateViewConfig::global()->setValue(KateViewConfig::WordCompletionRemoveTail, true);
     TestPressKey("\\home\\down\\right\\right\\right\\ctrl- \\enter"); // Cut off tail.
@@ -569,9 +526,12 @@ void CompletionTest::CompletionTests()
     TestPressKey("\\home\\down\\right\\right\\right\\ctrl- \\enter\\ctrl-c"); // Don't cut off tail.
     fakeCodeCompletionModel->setRemoveTailOnComplete(true);
     KateViewConfig::global()->setValue(KateViewConfig::WordCompletionRemoveTail, true);
+    FinishTest("functionwithargs(firstArg)\nnoargfunction()\ncompletionA\ncompletionAtail");
+
     // Replay.
     fakeCodeCompletionModel->setFailTestOnInvocation(true);
     kate_document->setText("funct\nnoa\ncomtail\ncomtail");
+    clearTrackedDocumentChanges();
     TestPressKey("gg.");
     FinishTest("functionwithargs(firstArg)\nnoargfunction()\ncompletionA\ncompletionAtail");
 
