@@ -6,8 +6,10 @@
 
 #include "katetextblock.h"
 #include "katetextbuffer.h"
+#include "katetextcursor.h"
+#include "katetextline.h"
+#include "katetextrange.h"
 
-#include <QVarLengthArray>
 
 namespace Kate
 {
@@ -69,7 +71,7 @@ void TextBlock::text(QString &text) const
     }
 }
 
-void TextBlock::wrapLine(const KTextEditor::Cursor &position, int fixStartLinesStartIndex)
+void TextBlock::wrapLine(const KTextEditor::Cursor position, int fixStartLinesStartIndex)
 {
     // calc internal line
     int line = position.line() - startLine();
@@ -166,7 +168,7 @@ void TextBlock::wrapLine(const KTextEditor::Cursor &position, int fixStartLinesS
 
     // we might need to invalidate ranges or notify about their changes
     // checkValidity might trigger delete of the range!
-    for (TextRange *range : qAsConst(changedRanges)) {
+    for (TextRange *range : std::as_const(changedRanges)) {
         // we need to do updateRange to ALWAYS ensure the line => range and back cache is updated
         // see MovingRangeTest::testLineWrapOrUnwrapUpdateRangeForLineCache
         updateRange(range);
@@ -265,7 +267,7 @@ void TextBlock::unwrapLine(int line, TextBlock *previousBlock, int fixStartLines
         // fixup the ranges that might be effected, because they moved from last line to this block
         // we might need to invalidate ranges or notify about their changes
         // checkValidity might trigger delete of the range!
-        for (TextRange *range : qAsConst(changedRanges)) {
+        for (TextRange *range : std::as_const(changedRanges)) {
             // update both blocks
             updateRange(range);
             previousBlock->updateRange(range);
@@ -337,7 +339,7 @@ void TextBlock::unwrapLine(int line, TextBlock *previousBlock, int fixStartLines
 
     // we might need to invalidate ranges or notify about their changes
     // checkValidity might trigger delete of the range!
-    for (TextRange *range : qAsConst(changedRanges)) {
+    for (TextRange *range : std::as_const(changedRanges)) {
         // we need to do updateRange to ALWAYS ensure the line => range and back cache is updated
         // see MovingRangeTest::testLineWrapOrUnwrapUpdateRangeForLineCache
         updateRange(range);
@@ -347,7 +349,7 @@ void TextBlock::unwrapLine(int line, TextBlock *previousBlock, int fixStartLines
     }
 }
 
-void TextBlock::insertText(const KTextEditor::Cursor &position, const QString &text)
+void TextBlock::insertText(const KTextEditor::Cursor position, const QString &text)
 {
     // calc internal line
     int line = position.line() - startLine();
@@ -411,7 +413,7 @@ void TextBlock::insertText(const KTextEditor::Cursor &position, const QString &t
 
     // we might need to invalidate ranges or notify about their changes
     // checkValidity might trigger delete of the range!
-    for (TextRange *range : qAsConst(changedRanges)) {
+    for (TextRange *range : std::as_const(changedRanges)) {
         range->checkValidity(range->toLineRange());
     }
 }
@@ -480,7 +482,7 @@ void TextBlock::removeText(const KTextEditor::Range &range, QString &removedText
 
     // we might need to invalidate ranges or notify about their changes
     // checkValidity might trigger delete of the range!
-    for (TextRange *range : qAsConst(changedRanges)) {
+    for (TextRange *range : std::as_const(changedRanges)) {
         range->checkValidity(range->toLineRange());
     }
 }
@@ -488,8 +490,9 @@ void TextBlock::removeText(const KTextEditor::Range &range, QString &removedText
 void TextBlock::debugPrint(int blockIndex) const
 {
     // print all blocks
-    for (size_t i = 0; i < m_lines.size(); ++i)
+    for (size_t i = 0; i < m_lines.size(); ++i) {
         printf("%4d - %4lld : %4d : '%s'\n", blockIndex, (unsigned long long)startLine() + i, m_lines.at(i)->text().size(), qPrintable(m_lines.at(i)->text()));
+    }
 }
 
 TextBlock *TextBlock::splitBlock(int fromLine)
@@ -704,7 +707,7 @@ void TextBlock::updateRange(TextRange *range)
     const int lineOffset = startLine - m_startLine;
 
     // enlarge cache if needed
-    if (m_cachedRangesForLine.size() <= lineOffset) {
+    if (m_cachedRangesForLine.size() <= (size_t)lineOffset) {
         m_cachedRangesForLine.resize(lineOffset + 1);
     }
 
