@@ -1,47 +1,38 @@
-/*  This file is part of the Kate project.
- *
- *  Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2010 Christoph Cullmann <cullmann@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 #ifndef KATE_TEXTBUFFER_H
 #define KATE_TEXTBUFFER_H
 
 #include <QObject>
-#include <QString>
-#include <QVector>
 #include <QSet>
+#include <QString>
 #include <QTextCodec>
+#include <QVector>
 
-#include <ktexteditor/document.h>
-
-#include "katedocument.h"
-#include <ktexteditor_export.h>
 #include "katetextblock.h"
-#include "katetextcursor.h"
-#include "katetextrange.h"
 #include "katetexthistory.h"
+#include <ktexteditor_export.h>
 
 // encoding prober
 #include <KEncodingProber>
 
+namespace KTextEditor
+{
+class DocumentPrivate;
+}
+
+class KCompressionDevice;
+
 namespace Kate
 {
-
+class TextRange;
+class TextCursor;
+class TextBlock;
+class TextLineData;
+typedef QSharedPointer<TextLineData> TextLine;
 /**
  * Class representing a text buffer.
  * The interface is line based, internally the text will be stored in blocks of text lines.
@@ -58,26 +49,22 @@ public:
     /**
      * End of line mode
      */
-    enum EndOfLineMode {
-        eolUnknown = -1
-      , eolUnix = 0
-      , eolDos = 1
-      , eolMac = 2
-    };
+    enum EndOfLineMode { eolUnknown = -1, eolUnix = 0, eolDos = 1, eolMac = 2 };
 
     /**
      * Construct an empty text buffer.
      * Empty means one empty line in one block.
      * @param parent parent qobject
      * @param blockSize block size in lines the buffer should try to hold, default 64 lines
+     * @param alwaysUseKAuth only set this for unit testing purposes
      */
-    TextBuffer(KTextEditor::DocumentPrivate *parent, int blockSize = 64, bool alwaysUseKAuth = false);
+    explicit TextBuffer(KTextEditor::DocumentPrivate *parent, int blockSize = 64, bool alwaysUseKAuth = false);
 
     /**
      * Destruct the text buffer
      * Virtual, we allow inheritance
      */
-    virtual ~TextBuffer();
+    ~TextBuffer() override;
 
     /**
      * Clears the buffer, reverts to initial empty state.
@@ -246,6 +233,20 @@ public:
      */
     TextLine line(int line) const;
 
+    /**
+     * Retrieve length for @p line
+     * @param line wanted line number
+     * @return length of the line
+     */
+    int lineLength(int line) const
+    {
+        // get block, this will assert on invalid line
+        int blockIndex = blockForLine(line);
+
+        // get line length
+        return m_blocks.at(blockIndex)->lineLength(line);
+    }
+
     /**
      * Retrieve text of complete buffer.
      * @return text for this buffer, lines separated by '\n'
@@ -278,7 +279,7 @@ public:
     }
 
     /**
-     * Query the revsion of this buffer before the ongoing editing transactions.
+     * Query the revision of this buffer before the ongoing editing transactions.
      * @return revision of buffer before current editing transaction altered it
      */
     qint64 editingLastRevision() const
@@ -338,7 +339,7 @@ public:
      * @param position line/column as cursor where to wrap
      * Virtual, can be overwritten.
      */
-    virtual void wrapLine(const KTextEditor::Cursor &position);
+    virtual void wrapLine(const KTextEditor::Cursor position);
 
     /**
      * Unwrap given line.
@@ -353,7 +354,7 @@ public:
      * @param text text to insert
      * Virtual, can be overwritten.
      */
-    virtual void insertText(const KTextEditor::Cursor &position, const QString &text);
+    virtual void insertText(const KTextEditor::Cursor position, const QString &text);
 
     /**
      * Remove text at given range. Does nothing if range is empty, beside some consistency checks.
@@ -405,7 +406,7 @@ Q_SIGNALS:
      * A line got wrapped.
      * @param position position where the wrap occurred
      */
-    void lineWrapped(const KTextEditor::Cursor &position);
+    void lineWrapped(const KTextEditor::Cursor position);
 
     /**
      * A line got unwrapped.
@@ -418,7 +419,7 @@ Q_SIGNALS:
      * @param position position where the insertion occurred
      * @param text inserted text
      */
-    void textInserted(const KTextEditor::Cursor &position, const QString &text);
+    void textInserted(const KTextEditor::Cursor position, const QString &text);
 
     /**
      * Text got removed.
@@ -428,6 +429,12 @@ Q_SIGNALS:
     void textRemoved(const KTextEditor::Range &range, const QString &text);
 
 private:
+    /**
+     * Save result which indicates an abstract reason why the operation has
+     * failed
+     */
+    enum class SaveResult { Failed = 0, MissingPermissions, Success };
+
     /**
      * Find block containing given line.
      * @param line we want to find block for this line
@@ -459,18 +466,37 @@ private:
 
     /**
      * A range changed, notify the views, in case of attributes or feedback.
-     * @param view which view is affected? 0 for all views
-     * @param startLine start line of change
-     * @param endLine end line of change
-     * @param rangeWithAttribute attribute changed or is active, this will perhaps lead to repaints
+     * @param view which view is affected? nullptr for all views
+     * @param lineRange line range that the change spans
+     * @param needsRepaint do we need to trigger repaints? e.g. if ranges with attributes change
      */
-    void notifyAboutRangeChange(KTextEditor::View *view, int startLine, int endLine, bool rangeWithAttribute);
+    void notifyAboutRangeChange(KTextEditor::View *view, KTextEditor::LineRange lineRange, bool needsRepaint);
 
     /**
      * Mark all modified lines as lines saved on disk (modified line system).
      */
     void markModifiedLinesAsSaved();
 
+    /**
+     * Save the current buffer content to the given already opened device
+     *
+     * @param filename path name for display/debugging purposes
+     * @param saveFile open device to write the buffer to
+     */
+    bool saveBuffer(const QString &filename, KCompressionDevice &saveFile);
+
+    /**
+     * Attempt to save the buffer content in the given filename location using
+     * current privileges.
+     */
+    SaveResult saveBufferUnprivileged(const QString &filename);
+
+    /**
+     * Attempt to save the buffer content in the given filename location using
+     * escalated privileges.
+     */
+    bool saveBufferEscalated(const QString &filename);
+
 public:
     /**
      * Gets the document to which this buffer is bound.
@@ -494,7 +520,12 @@ public:
      * @param rangesWithAttributeOnly only return ranges which have a attribute set
      * @return list of ranges affecting this line
      */
-    QList<TextRange *> rangesForLine(int line, KTextEditor::View *view, bool rangesWithAttributeOnly) const;
+    QVector<TextRange *> rangesForLine(int line, KTextEditor::View *view, bool rangesWithAttributeOnly) const
+    {
+        // get block, this will assert on invalid line
+        const int blockIndex = blockForLine(line);
+        return m_blocks.at(blockIndex)->rangesForLine(line, view, rangesWithAttributeOnly);
+    }
 
     /**
      * Check if the given range pointer is still valid.
@@ -550,7 +581,7 @@ private:
     /**
      * List of blocks which contain the lines of this buffer
      */
-    QVector<TextBlock *> m_blocks;
+    std::vector<TextBlock *> m_blocks;
 
     /**
      * Number of lines in buffer
