@@ -1,28 +1,14 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: KDE Developers
 
-    Copyright (C) KDE Developers
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kateviinputmode.h"
 #include "kateconfig.h"
+#include "katedocument.h"
 #include "kateviewinternal.h"
 #include <vimode/emulatedcommandbar/emulatedcommandbar.h>
-#include <vimode/inputmodemanager.h>
 #include <vimode/macrorecorder.h>
 #include <vimode/marks.h>
 #include <vimode/modes/replacevimode.h>
@@ -69,22 +55,17 @@ KateViInputMode::KateViInputMode(KateViewInternal *viewInternal, KateVi::GlobalS
     , m_viGlobal(global)
     , m_caret(KateRenderer::Block)
     , m_nextKeypressIsOverriddenShortCut(false)
+    , m_relLineNumbers(KateViewConfig::global()->viRelativeLineNumbers())
     , m_activated(false)
+    , m_viModeManager(new KateVi::InputModeManager(this, view(), viewInternal))
 {
-    m_relLineNumbers = KateViewConfig::global()->viRelativeLineNumbers();
-    m_viModeManager = new KateVi::InputModeManager(this, view(), viewInternal);
-}
-
-KateViInputMode::~KateViInputMode()
-{
-    delete m_viModeManager;
 }
 
 void KateViInputMode::activate()
 {
     m_activated = true;
     setCaretStyle(KateRenderer::Block); // TODO: can we end up in insert mode?
-    reset();                            // TODO: is this necessary? (well, not anymore I guess)
+    reset(); // TODO: is this necessary? (well, not anymore I guess)
 
     if (view()->selection()) {
         m_viModeManager->changeViMode(KateVi::VisualMode);
@@ -112,11 +93,12 @@ void KateViInputMode::reset()
         m_viModeEmulatedCommandBar->hideMe();
     }
 
-    delete m_viModeManager;
-    m_viModeManager = new KateVi::InputModeManager(this, view(), viewInternal());
+    // ensure first the old stuff is deleted and then the new manager is constructed
+    m_viModeManager.reset();
+    m_viModeManager.reset(new KateVi::InputModeManager(this, view(), viewInternal()));
 
     if (m_viModeEmulatedCommandBar) {
-        m_viModeEmulatedCommandBar->setViInputModeManager(m_viModeManager);
+        m_viModeEmulatedCommandBar->setViInputModeManager(m_viModeManager.get());
     }
 }
 
@@ -268,7 +250,7 @@ void KateViInputMode::showViModeEmulatedCommandBar()
 KateVi::EmulatedCommandBar *KateViInputMode::viModeEmulatedCommandBar()
 {
     if (!m_viModeEmulatedCommandBar) {
-        m_viModeEmulatedCommandBar = new KateVi::EmulatedCommandBar(this, m_viModeManager, view());
+        m_viModeEmulatedCommandBar = new KateVi::EmulatedCommandBar(this, m_viModeManager.get(), view());
         m_viModeEmulatedCommandBar->hide();
     }
 
@@ -290,7 +272,7 @@ bool KateViInputMode::keyPress(QKeyEvent *e)
     }
 
     if (m_viModeManager->handleKeypress(e)) {
-        emit view()->viewModeChanged(view(), viewMode());
+        Q_EMIT view()->viewModeChanged(view(), viewMode());
         return true;
     }
 
