@@ -4,7 +4,6 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-
 #include "ontheflycheck.h"
 
 #include <QRegularExpression>
@@ -42,13 +41,13 @@ KateOnTheFlyChecker::KateOnTheFlyChecker(KTextEditor::DocumentPrivate *document)
 
     m_viewRefreshTimer = new QTimer(this);
     m_viewRefreshTimer->setSingleShot(true);
-    connect(m_viewRefreshTimer, SIGNAL(timeout()), this, SLOT(viewRefreshTimeout()));
+    connect(m_viewRefreshTimer, &QTimer::timeout, this, &KateOnTheFlyChecker::viewRefreshTimeout);
 
-    connect(document, &KTextEditor::DocumentPrivate::textInserted, this, &KateOnTheFlyChecker::textInserted);
+    connect(document, &KTextEditor::DocumentPrivate::textInsertedRange, this, &KateOnTheFlyChecker::textInserted);
     connect(document, &KTextEditor::DocumentPrivate::textRemoved, this, &KateOnTheFlyChecker::textRemoved);
-    connect(document, SIGNAL(viewCreated(KTextEditor::Document *, KTextEditor::View *)), this, SLOT(addView(KTextEditor::Document *, KTextEditor::View *)));
-    connect(document, SIGNAL(highlightingModeChanged(KTextEditor::Document *)), this, SLOT(updateConfig()));
-    connect(&document->buffer(), SIGNAL(respellCheckBlock(int, int)), this, SLOT(handleRespellCheckBlock(int, int)));
+    connect(document, &KTextEditor::DocumentPrivate::viewCreated, this, &KateOnTheFlyChecker::addView);
+    connect(document, &KTextEditor::DocumentPrivate::highlightingModeChanged, this, &KateOnTheFlyChecker::updateConfig);
+    connect(&document->buffer(), &KateBuffer::respellCheckBlock, this, &KateOnTheFlyChecker::handleRespellCheckBlock);
 
     connect(document, &KTextEditor::Document::reloaded, this, [this](KTextEditor::Document *) {
         refreshSpellCheck();
@@ -69,7 +68,7 @@ KateOnTheFlyChecker::~KateOnTheFlyChecker()
     freeDocument();
 }
 
-QPair<KTextEditor::Range, QString> KateOnTheFlyChecker::getMisspelledItem(const KTextEditor::Cursor &cursor) const
+QPair<KTextEditor::Range, QString> KateOnTheFlyChecker::getMisspelledItem(const KTextEditor::Cursor cursor) const
 {
     for (const MisspelledItem &item : m_misspelledList) {
         KTextEditor::MovingRange *movingRange = item.first;
@@ -267,7 +266,8 @@ void KateOnTheFlyChecker::handleRemovedText(const KTextEditor::Range &range)
     if (spellCheckInProgress) {
         KTextEditor::MovingRange *spellCheckRange = m_currentlyCheckedItem.first;
         ON_THE_FLY_DEBUG << *spellCheckRange;
-        if (m_document->documentRange().contains(*spellCheckRange) && (rangesAdjacent(*spellCheckRange, range) || spellCheckRange->contains(range)) && !spellCheckRange->isEmpty()) {
+        if (m_document->documentRange().contains(*spellCheckRange) && (rangesAdjacent(*spellCheckRange, range) || spellCheckRange->contains(range))
+            && !spellCheckRange->isEmpty()) {
             rangesToReCheck.push_back(*spellCheckRange);
             ON_THE_FLY_DEBUG << "added the range " << *spellCheckRange;
             stopCurrentSpellCheck();
@@ -372,8 +372,8 @@ void KateOnTheFlyChecker::performSpellCheck()
     }
     if (!m_backgroundChecker) {
         m_backgroundChecker = new Sonnet::BackgroundChecker(m_speller, this);
-        connect(m_backgroundChecker, SIGNAL(misspelling(QString, int)), this, SLOT(misspelling(QString, int)));
-        connect(m_backgroundChecker, SIGNAL(done()), this, SLOT(spellCheckDone()));
+        connect(m_backgroundChecker, &Sonnet::BackgroundChecker::misspelling, this, &KateOnTheFlyChecker::misspelling);
+        connect(m_backgroundChecker, &Sonnet::BackgroundChecker::done, this, &KateOnTheFlyChecker::spellCheckDone);
 
         KateSpellCheckManager *m_spellCheckManager = KTextEditor::EditorPrivate::self()->spellCheckManager();
         connect(m_spellCheckManager, &KateSpellCheckManager::wordAddedToDictionary, this, &KateOnTheFlyChecker::addToDictionary);
@@ -519,18 +519,21 @@ void KateOnTheFlyChecker::deleteMovingRanges(const QList<KTextEditor::MovingRang
     }
 }
 
-KTextEditor::Range KateOnTheFlyChecker::findWordBoundaries(const KTextEditor::Cursor &begin, const KTextEditor::Cursor &end)
+KTextEditor::Range KateOnTheFlyChecker::findWordBoundaries(const KTextEditor::Cursor begin, const KTextEditor::Cursor end)
 {
     // FIXME: QTextBoundaryFinder should be ideally used for this, but it is currently
     //        still broken in Qt
-    const QRegularExpression boundaryRegExp(QLatin1String("\\b"));
-    const QRegularExpression boundaryQuoteRegExp(QLatin1String("\\b\\w+'\\w*$")); // handle spell checking of QLatin1String("isn't"), QLatin1String("doesn't"), etc.
-    const QRegularExpression extendedBoundaryRegExp(QLatin1String("(\\W|$)"));
-    const QRegularExpression extendedBoundaryQuoteRegExp(QLatin1String("^\\w*'\\w+\\b")); // see above
-    KTextEditor::DocumentPrivate::OffsetList decToEncOffsetList, encToDecOffsetList;
+    static const QRegularExpression boundaryRegExp(QStringLiteral("\\b"), QRegularExpression::UseUnicodePropertiesOption);
+    // handle spell checking of QLatin1String("isn't"), QLatin1String("doesn't"), etc.
+    static const QRegularExpression boundaryQuoteRegExp(QStringLiteral("\\b\\w+'\\w*$"), QRegularExpression::UseUnicodePropertiesOption);
+    static const QRegularExpression extendedBoundaryRegExp(QStringLiteral("\\W|$"), QRegularExpression::UseUnicodePropertiesOption);
+    static const QRegularExpression extendedBoundaryQuoteRegExp(QStringLiteral("^\\w*'\\w+\\b"), QRegularExpression::UseUnicodePropertiesOption); // see above
+    KTextEditor::DocumentPrivate::OffsetList decToEncOffsetList;
+    KTextEditor::DocumentPrivate::OffsetList encToDecOffsetList;
     const int startLine = begin.line();
     const int startColumn = begin.column();
-    KTextEditor::Cursor boundaryStart, boundaryEnd;
+    KTextEditor::Cursor boundaryStart;
+    KTextEditor::Cursor boundaryEnd;
     // first we take care of the start position
     const KTextEditor::Range startLineRange(startLine, 0, startLine, m_document->lineLength(startLine));
     QString decodedLineText = m_document->decodeCharacters(startLineRange, decToEncOffsetList, encToDecOffsetList);
@@ -539,7 +542,7 @@ KTextEditor::Range KateOnTheFlyChecker::findWordBoundaries(const KTextEditor::Cu
     boundaryStart.setLine(startLine);
     int match = text.lastIndexOf(boundaryQuoteRegExp);
     if (match < 0) {
-        match = text.lastIndexOf(boundaryRegExp);
+        match = text.lastIndexOf(boundaryRegExp, -2);
     }
     boundaryStart.setColumn(m_document->computePositionWrtOffsets(decToEncOffsetList, qMax(0, match)));
     // and now the end position
@@ -583,7 +586,8 @@ void KateOnTheFlyChecker::misspelling(const QString &word, int start)
     int rangeStart = spellCheckRange->start().column();
     int translatedEnd = m_document->computePositionWrtOffsets(m_currentDecToEncOffsetList, start + word.length());
 
-    KTextEditor::MovingRange *movingRange = m_document->newMovingRange(KTextEditor::Range(line, rangeStart + translatedStart, line, rangeStart + translatedEnd));
+    KTextEditor::MovingRange *movingRange =
+        m_document->newMovingRange(KTextEditor::Range(line, rangeStart + translatedStart, line, rangeStart + translatedEnd));
     movingRange->setFeedback(this);
     KTextEditor::Attribute *attribute = new KTextEditor::Attribute();
     attribute->setUnderlineStyle(QTextCharFormat::SpellCheckUnderline);
@@ -650,8 +654,9 @@ void KateOnTheFlyChecker::addView(KTextEditor::Document *document, KTextEditor::
     Q_ASSERT(document == m_document);
     Q_UNUSED(document);
     ON_THE_FLY_DEBUG;
-    connect(view, SIGNAL(destroyed(QObject *)), this, SLOT(viewDestroyed(QObject *)));
-    connect(view, SIGNAL(displayRangeChanged(KTextEditor::ViewPrivate *)), this, SLOT(restartViewRefreshTimer(KTextEditor::ViewPrivate *)));
+    auto *viewPrivate = static_cast<KTextEditor::ViewPrivate *>(view);
+    connect(viewPrivate, &KTextEditor::ViewPrivate::destroyed, this, &KateOnTheFlyChecker::viewDestroyed);
+    connect(viewPrivate, &KTextEditor::ViewPrivate::displayRangeChanged, this, &KateOnTheFlyChecker::restartViewRefreshTimer);
     updateInstalledMovingRanges(static_cast<KTextEditor::ViewPrivate *>(view));
 }
 
@@ -678,7 +683,7 @@ void KateOnTheFlyChecker::updateInstalledMovingRanges(KTextEditor::ViewPrivate *
     ON_THE_FLY_DEBUG << "new range: " << newDisplayRange;
     ON_THE_FLY_DEBUG << "old range: " << oldDisplayRange;
     QList<KTextEditor::MovingRange *> toDelete;
-    for (const MisspelledItem &item : qAsConst(m_misspelledList)) {
+    for (const MisspelledItem &item : std::as_const(m_misspelledList)) {
         KTextEditor::MovingRange *movingRange = item.first;
         if (!movingRange->overlaps(newDisplayRange)) {
             bool stillVisible = false;
@@ -743,7 +748,8 @@ void KateOnTheFlyChecker::queueSpellCheckVisibleRange(KTextEditor::ViewPrivate *
     const MovingRangeList highlightsList = installedMovingRanges(intersection);
     deleteMovingRanges(highlightsList);
 
-    QList<QPair<KTextEditor::Range, QString>> spellCheckRanges = KTextEditor::EditorPrivate::self()->spellCheckManager()->spellCheckRanges(m_document, intersection, true);
+    QList<QPair<KTextEditor::Range, QString>> spellCheckRanges =
+        KTextEditor::EditorPrivate::self()->spellCheckManager()->spellCheckRanges(m_document, intersection, true);
     // we queue them up in reverse
     QListIterator<QPair<KTextEditor::Range, QString>> i(spellCheckRanges);
     i.toBack();
@@ -762,7 +768,8 @@ void KateOnTheFlyChecker::queueLineSpellCheck(KTextEditor::DocumentPrivate *kate
     const MovingRangeList highlightsList = installedMovingRanges(range);
     deleteMovingRanges(highlightsList);
 
-    QList<QPair<KTextEditor::Range, QString>> spellCheckRanges = KTextEditor::EditorPrivate::self()->spellCheckManager()->spellCheckRanges(kateDocument, range, true);
+    QList<QPair<KTextEditor::Range, QString>> spellCheckRanges =
+        KTextEditor::EditorPrivate::self()->spellCheckManager()->spellCheckRanges(kateDocument, range, true);
     // we queue them up in reverse
     QListIterator<QPair<KTextEditor::Range, QString>> i(spellCheckRanges);
     i.toBack();
@@ -840,7 +847,7 @@ void KateOnTheFlyChecker::deleteMovingRangeQuickly(KTextEditor::MovingRange *ran
 
 void KateOnTheFlyChecker::handleModifiedRanges()
 {
-    for (const ModificationItem &item : qAsConst(m_modificationList)) {
+    for (const ModificationItem &item : std::as_const(m_modificationList)) {
         KTextEditor::MovingRange *movingRange = item.second;
         KTextEditor::Range range = *movingRange;
         deleteMovingRangeQuickly(movingRange);
@@ -871,7 +878,7 @@ bool KateOnTheFlyChecker::removeRangeFromModificationList(KTextEditor::MovingRan
 
 void KateOnTheFlyChecker::clearModificationList()
 {
-    for (const ModificationItem &item : qAsConst(m_modificationList)) {
+    for (const ModificationItem &item : std::as_const(m_modificationList)) {
         KTextEditor::MovingRange *movingRange = item.second;
         deleteMovingRangeQuickly(movingRange);
     }
