@@ -1,27 +1,13 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2009-2010 Michel Ludwig <michel.ludwig@kdemail.net>
+    SPDX-FileCopyrightText: 2008 Mirko Stocker <me@misto.ch>
+    SPDX-FileCopyrightText: 2004-2005 Anders Lund <anders@alweb.dk>
+    SPDX-FileCopyrightText: 2002 John Firebaugh <jfirebaugh@kde.org>
+    SPDX-FileCopyrightText: 2001-2004 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
 
-    Copyright (C) 2009-2010 by Michel Ludwig <michel.ludwig@kdemail.net>
-    Copyright (C) 2008 Mirko Stocker <me@misto.ch>
-    Copyright (C) 2004-2005 Anders Lund <anders@alweb.dk>
-    Copyright (C) 2002 John Firebaugh <jfirebaugh@kde.org>
-    Copyright (C) 2001-2004 Christoph Cullmann <cullmann@kde.org>
-    Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
-    Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "spellcheckdialog.h"
@@ -66,7 +52,7 @@ void KateSpellCheckDialog::createActions(KActionCollection *ac)
     ac->addAction(QStringLiteral("tools_spelling_from_cursor"), a);
     a->setIcon(QIcon::fromTheme(QStringLiteral("tools-check-spelling")));
     a->setWhatsThis(i18n("Check the document's spelling from the cursor and forward"));
-    connect(a, SIGNAL(triggered()), this, SLOT(spellcheckFromCursor()));
+    connect(a, &QAction::triggered, this, &KateSpellCheckDialog::spellcheckFromCursor);
 }
 
 void KateSpellCheckDialog::spellcheckFromCursor()
@@ -92,7 +78,7 @@ void KateSpellCheckDialog::spellcheck()
     }
 }
 
-void KateSpellCheckDialog::spellcheck(const KTextEditor::Cursor &from, const KTextEditor::Cursor &to)
+void KateSpellCheckDialog::spellcheck(const KTextEditor::Cursor from, const KTextEditor::Cursor to)
 {
     KTextEditor::Cursor start = from;
     KTextEditor::Cursor end = to;
@@ -116,17 +102,17 @@ void KateSpellCheckDialog::spellcheck(const KTextEditor::Cursor &from, const KTe
         m_sonnetDialog->showSpellCheckCompletionMessage();
         m_sonnetDialog->setSpellCheckContinuedAfterReplacement(false);
 
-        connect(m_sonnetDialog, SIGNAL(done(QString)), this, SLOT(installNextSpellCheckRange()));
+        connect(m_sonnetDialog, &SpellCheckBar::done, this, &KateSpellCheckDialog::installNextSpellCheckRange);
 
-        connect(m_sonnetDialog, SIGNAL(replace(QString, int, QString)), this, SLOT(corrected(QString, int, QString)));
+        connect(m_sonnetDialog, &SpellCheckBar::replace, this, &KateSpellCheckDialog::corrected);
 
-        connect(m_sonnetDialog, SIGNAL(misspelling(QString, int)), this, SLOT(misspelling(QString, int)));
+        connect(m_sonnetDialog, &SpellCheckBar::misspelling, this, &KateSpellCheckDialog::misspelling);
 
-        connect(m_sonnetDialog, SIGNAL(cancel()), this, SLOT(cancelClicked()));
+        connect(m_sonnetDialog, &SpellCheckBar::cancel, this, &KateSpellCheckDialog::cancelClicked);
 
-        connect(m_sonnetDialog, SIGNAL(destroyed(QObject *)), this, SLOT(objectDestroyed(QObject *)));
+        connect(m_sonnetDialog, &SpellCheckBar::destroyed, this, &KateSpellCheckDialog::objectDestroyed);
 
-        connect(m_sonnetDialog, SIGNAL(languageChanged(QString)), this, SLOT(languageChanged(QString)));
+        connect(m_sonnetDialog, &SpellCheckBar::languageChanged, this, &KateSpellCheckDialog::languageChanged);
     }
 
     m_view->bottomViewBar()->addBarWidget(m_sonnetDialog);
@@ -135,7 +121,8 @@ void KateSpellCheckDialog::spellcheck(const KTextEditor::Cursor &from, const KTe
     m_previousGivenSpellCheckLanguage.clear();
     delete m_globalSpellCheckRange;
     // we expand to handle the situation when the last word in the range is replace by a new one
-    m_globalSpellCheckRange = m_view->doc()->newMovingRange(KTextEditor::Range(start, end), KTextEditor::MovingRange::ExpandLeft | KTextEditor::MovingRange::ExpandRight);
+    m_globalSpellCheckRange =
+        m_view->doc()->newMovingRange(KTextEditor::Range(start, end), KTextEditor::MovingRange::ExpandLeft | KTextEditor::MovingRange::ExpandRight);
     m_spellCheckCancelledByUser = false;
     performSpellCheck(*m_globalSpellCheckRange);
 }
@@ -225,7 +212,8 @@ void KateSpellCheckDialog::installNextSpellCheckRange()
     while (m_currentLanguageRangeIterator != m_languagesInSpellCheckRange.end()) {
         const KTextEditor::Range &currentLanguageRange = (*m_currentLanguageRangeIterator).first;
         const QString &dictionary = (*m_currentLanguageRangeIterator).second;
-        KTextEditor::Range languageSubRange = (nextRangeBegin.isValid() ? KTextEditor::Range(nextRangeBegin, currentLanguageRange.end()) : currentLanguageRange);
+        KTextEditor::Range languageSubRange =
+            (nextRangeBegin.isValid() ? KTextEditor::Range(nextRangeBegin, currentLanguageRange.end()) : currentLanguageRange);
         rangeDictionaryPairList = spellCheckManager->spellCheckWrtHighlightingRanges(m_view->doc(), languageSubRange, dictionary, false, true);
         Q_ASSERT(rangeDictionaryPairList.size() <= 1);
         if (rangeDictionaryPairList.size() == 0) {
